#ifndef H_PROCMAN_LSOF_1161179202
#define H_PROCMAN_LSOF_1161179202

#include <glib/gmacros.h>
#include "procman.h"

void procman_lsof(ProcData *data);

#endif /* H_PROCMAN_LSOF_1161179202 */
